==> v1.8.3.tar.gz: zyos_go_order_relate_rule/svc/extend_agent_commission.go <==
package svc

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db/model"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/md"
	zhios_order_relate_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils"
	"encoding/json"
	"time"
	"xorm.io/xorm"
)

//加入区域代理直推上级分佣 抽成部分
/***
commission 总佣金
bili	抽成 除以100之后的
uid	 用户id
oid 订单号
pvd 渠道
*/
func AddExtendAgentCommission(eg *xorm.Engine, args map[string]string) {
	user, err := db.UserProfileFindByID(eg, args["uid"])
	if err != nil || user == nil {
		return
	}
	if user.ParentUid == 0 {
		return
	}
	//判断是不是代理
	//查出用户是否区域代理
	agentUser, err := db.GetCountByRegionalAgentUserInfoByParams(eg, map[string]interface{}{
		"key":   "uid",
		"value": user.Uid,
	})
	if agentUser == nil || err != nil {
		return
	}
	// 有效期计算
	if agentUser.IsFailure == 1 {
		return
	}
	now := time.Now().Unix()
	if agentUser.FailureTime > 0 && agentUser.FailureTime < int(now) {
		return
	}

	commissionOpt, err := db.DbsPlanCommissionById(eg, zhios_order_relate_utils.StrToInt(args["plan_commission_id"]))
	if err != nil || commissionOpt == nil || commissionOpt.Id == 0 {
		return
	}
	var subsidyTmp = make(map[int]*md.ExtendRewardLvGrade)
	var tmp map[int]*md.ExtendRewardLvGrade
	if err := json.Unmarshal([]byte(commissionOpt.Data), &tmp); err != nil {
		return
	}
	for _, v := range tmp {
		subsidyTmp[v.Lv] = v
	}
	userProfile, err := db.UserProfileFindByID(eg, args["uid"])
	if err != nil || userProfile == nil {
		return
	}
	if userProfile.ParentUid == 0 {
		return
	}
	//查询用户等级
	parentUser, err := db.UserFindByID(eg, userProfile.ParentUid)
	if err != nil || parentUser == nil {
		return
	}
	lvGrade := subsidyTmp[parentUser.Level]
	var rewardList = make(map[string]md.ExtendPriceRewardList)
	for _, v := range lvGrade.ExtendPriceRewardList {
		rewardList[v.CoinID] = v
	}
	//判断有没有存过
	relate, _ := db.GetExtendAgentCommissionRelate(eg, args["oid"], args["pvd"])
	if relate != nil {
		return
	}

	for k, v := range rewardList {
		var amount float64 = 0
		rewardData := v
		reward := md.ExtendPriceRewardListDetail{}
		if agentUser.Level == 1 {
			reward = rewardData.ProvinceAgent
		}
		if agentUser.Level == 2 {
			reward = rewardData.CityAgent
		}
		if agentUser.Level == 3 {
			reward = rewardData.AreaAgent
		}
		amount = zhios_order_relate_utils.StrToFloat64(args["commission"]) * zhios_order_relate_utils.StrToFloat64(reward.ExtendAgentBili) / 100
		if amount == 0 {
			continue
		}
		var ord = model.ExtendAgentCommissionRelate{
			Uid:        user.ParentUid,
			FormUid:    user.Uid,
			Pvd:        args["pvd"],
			Oid:        args["oid"],
			CreateTime: time.Now(),
			Amount:     zhios_order_relate_utils.Float64ToStrByPrec(amount, 4),
			Rate:       args["bili"],
			CoinId:     zhios_order_relate_utils.StrToInt(k),
		}
		eg.InsertOne(&ord)
	}

	return
}

==> v1.8.4.tar.gz: zyos_go_order_relate_rule/svc/extend_agent_commission.go <==
package svc

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db/model"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/md"
	zhios_order_relate_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils"
	"encoding/json"
	"time"
	"xorm.io/xorm"
)

//加入区域代理直推上级分佣 抽成部分
/***
commission 总佣金
bili	抽成 除以100之后的
uid	 用户id
oid 订单号
pvd 渠道
*/
func AddExtendAgentCommission(eg *xorm.Engine, args map[string]string) {
	user, err := db.UserProfileFindByID(eg, args["uid"])
	if err != nil || user == nil {
		return
	}
	if user.ParentUid == 0 {
		return
	}
	//判断是不是代理
	//查出用户是否区域代理
	agentUser, err := db.GetCountByRegionalAgentUserInfoByParams(eg, map[string]interface{}{
		"key":   "uid",
		"value": user.Uid,
	})
	if agentUser == nil || err != nil {
		return
	}
	// 有效期计算
	if agentUser.IsFailure == 1 {
		return
	}
	now := time.Now().Unix()
	if agentUser.FailureTime > 0 && agentUser.FailureTime < int(now) {
		return
	}

	commissionOpt, err := db.DbsPlanCommissionById(eg, zhios_order_relate_utils.StrToInt(args["plan_commission_id"]))
	if err != nil || commissionOpt == nil || commissionOpt.Id == 0 {
		return
	}
	var subsidyTmp = make(map[int]*md.ExtendRewardLvGrade)
	var tmp map[int]*md.ExtendRewardLvGrade
	if err := json.Unmarshal([]byte(commissionOpt.Data), &tmp); err != nil {
		return
	}
	for _, v := range tmp {
		subsidyTmp[v.Lv] = v
	}
	userProfile, err := db.UserProfileFindByID(eg, args["uid"])
	if err != nil || userProfile == nil {
		return
	}
	if userProfile.ParentUid == 0 {
		return
	}
	//查询用户等级
	parentUser, err := db.UserFindByID(eg, userProfile.ParentUid)
	if err != nil || parentUser == nil {
		return
	}
	lvGrade := subsidyTmp[parentUser.Level]
	var rewardList = make(map[string]md.ExtendPriceRewardListDetail)
	if agentUser.Level == 1 {
		rewardList = lvGrade.ExtendPriceRewardBuyGoodsProvince
	}
	if agentUser.Level == 2 {
		rewardList = lvGrade.ExtendPriceRewardBuyGoodsCity
	}
	if agentUser.Level == 3 {
		rewardList = lvGrade.ExtendPriceRewardBuyGoodsArea
	}
	//判断有没有存过
	relate, _ := db.GetExtendAgentCommissionRelate(eg, args["oid"], args["pvd"])
	if relate != nil {
		return
	}

	for k, v := range rewardList {
		var amount float64 = 0
		amount = zhios_order_relate_utils.StrToFloat64(args["commission"]) * zhios_order_relate_utils.StrToFloat64(v.Bili) / 100
		if amount == 0 {
			continue
		}
		var ord = model.ExtendAgentCommissionRelate{
			Uid:        user.ParentUid,
			FormUid:    user.Uid,
			Pvd:        args["pvd"],
			Oid:        args["oid"],
			CreateTime: time.Now(),
			Amount:     zhios_order_relate_utils.Float64ToStrByPrec(amount, 4),
			Rate:       args["bili"],
			CoinId:     zhios_order_relate_utils.StrToInt(k),
		}
		eg.InsertOne(&ord)
	}

	return
}
